{% extends "./browse.html" %} {% comment %} Copyright (C) 2017-2021 The Software Heritage developers See the AUTHORS file at the top-level directory of this distribution License: GNU Affero General Public License version 3, or any later version See top-level LICENSE file for more information {% endcomment %} {% load swh_templatetags %} {% block swh-browse-content %}
{% include "includes/branch-search.html" %}

Name | Target | Message | Date
--- | --- | --- | ---
{% if displayed_releases|length > 0 %} {% for release in displayed_releases %}
{% if release.alias %} {% else %} {% endif %} {{ release.name }} | {{ release.target|slice:":7" }} | {{ release.message }} | {{ release.date }}
{% endfor %} {% else %}
{% if search_string %} No release names containing {{search_string}} have been found! {% else %} The list of releases is empty! {% endif %}
{% endif %}

{% endblock %} {% block swh-browse-after-content %} {% if prev_releases_url or next_releases_url %}

{% if prev_releases_url %}
- Previous
{% else %}
- Previous
{% endif %} {% if next_releases_url %}
- Next
{% else %}
- Next
{% endif %}

{% endif %} {% endblock %}